==> com.idenfy.idenfySdk-1.0.4-sources.jar: com/idenfy/idenfySdk/SdkResponseModels/AutenticationResult/ErrorMessage.java <==
package com.idenfy.idenfySdk.SdkResponseModels.AutenticationResult;

import android.os.Parcel;
import android.os.Parcelable;

import com.google.gson.annotations.Expose;
import com.google.gson.annotations.SerializedName;

public class ErrorMessage implements Parcelable {

    @SerializedName("en")
    @Expose
    private String en;
    @SerializedName("lt")
    @Expose
    private String lt;
    @SerializedName("ru")
    @Expose
    private String ru;

    protected ErrorMessage(Parcel in) {
        en = in.readString();
        lt = in.readString();
        ru = in.readString();
    }

    public static final Creator<ErrorMessage> CREATOR = new Creator<ErrorMessage>() {
        @Override
        public ErrorMessage createFromParcel(Parcel in) {
            return new ErrorMessage(in);
        }

        @Override
        public ErrorMessage[] newArray(int size) {
            return new ErrorMessage[size];
        }
    };

    public String getEn() {
        return en;
    }

    public void setEn(String en) {
        this.en = en;
    }

    public String getLt() {
        return lt;
    }

    public void setLt(String lt) {
        this.lt = lt;
    }

    public String getRu() {
        return ru;
    }

    public void setRu(String ru) {
        this.ru = ru;
    }

    @Override
    public int describeContents() {
        return 0;
    }

    @Override
    public void writeToParcel(Parcel dest, int flags) {
        dest.writeString(en);
        dest.writeString(lt);
        dest.writeString(ru);
    }
}

==> com.idenfy.idenfySdk-1.1.5.4-sources.jar: com/idenfy/idenfySdk/SdkResponseModels/AutenticationResult/ErrorMessage.java <==
package com.idenfy.idenfySdk.SdkResponseModels.AutenticationResult;

import android.os.Parcel;
import android.os.Parcelable;

import com.google.gson.annotations.Expose;
import com.google.gson.annotations.SerializedName;

public class ErrorMessage implements Parcelable {

    @SerializedName("en")
    @Expose
    private String en;
    @SerializedName("lt")
    @Expose
    private String lt;
    @SerializedName("ru")
    @Expose
    private String ru;

    @SerializedName("pl")
    @Expose
    private String pl;

    protected ErrorMessage(Parcel in) {
        en = in.readString();
        lt = in.readString();
        ru = in.readString();
    }

    public static final Creator<ErrorMessage> CREATOR = new Creator<ErrorMessage>() {
        @Override
        public ErrorMessage createFromParcel(Parcel in) {
            return new ErrorMessage(in);
        }

        @Override
        public ErrorMessage[] newArray(int size) {
            return new ErrorMessage[size];
        }
    };

    public String getEn() {
        return en;
    }

    public void setEn(String en) {
        this.en = en;
    }

    public String getLt() {
        return lt;
    }

    public void setLt(String lt) {
        this.lt = lt;
    }

    public String getRu() {
        return ru;
    }

    public void setRu(String ru) {
        this.ru = ru;
    }

    public String getPl() {
        return pl;
    }

    public void setPl(String pl) {
        this.pl = pl;
    }

    @Override
    public int describeContents() {
        return 0;
    }

    @Override
    public void writeToParcel(Parcel dest, int flags) {
        dest.writeString(en);
        dest.writeString(lt);
        dest.writeString(ru);
    }
}
